# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class SearchRequestAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'limit': 'int',
        'threshold': 'float',
        'group_ids': '[int]',
    }

    attribute_map = {
        'limit': 'limit',
        'threshold': 'threshold',
        'group_ids': 'group_ids',
    }

    def __init__(self, limit=100, threshold=None, group_ids=None, local_vars_configuration=None):  # noqa: E501
        """SearchRequestAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._limit = None
        self._threshold = None
        self._group_ids = None
        self.discriminator = None

        if limit is not None:
            self.limit = limit
        if threshold is not None:
            self.threshold = threshold
        if group_ids is not None:
            self.group_ids = group_ids

    @property
    def limit(self):
        """Gets the limit of this SearchRequestAllOf.  # noqa: E501

        The number of returned Persons limit.  # noqa: E501

        :return: The limit of this SearchRequestAllOf.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchRequestAllOf.

        The number of returned Persons limit.  # noqa: E501

        :param limit: The limit of this SearchRequestAllOf.  # noqa: E501
        :type limit: int
        """

        self._limit = limit

    @property
    def threshold(self):
        """Gets the threshold of this SearchRequestAllOf.  # noqa: E501

        Similarity threshold.  # noqa: E501

        :return: The threshold of this SearchRequestAllOf.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this SearchRequestAllOf.

        Similarity threshold.  # noqa: E501

        :param threshold: The threshold of this SearchRequestAllOf.  # noqa: E501
        :type threshold: float
        """

        self._threshold = threshold

    @property
    def group_ids(self):
        """Gets the group_ids of this SearchRequestAllOf.  # noqa: E501

        The IDs of the groups in which the search is performed.  # noqa: E501

        :return: The group_ids of this SearchRequestAllOf.  # noqa: E501
        :rtype: [int]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """Sets the group_ids of this SearchRequestAllOf.

        The IDs of the groups in which the search is performed.  # noqa: E501

        :param group_ids: The group_ids of this SearchRequestAllOf.  # noqa: E501
        :type group_ids: [int]
        """

        self._group_ids = group_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequestAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRequestAllOf):
            return True

        return self.to_dict() != other.to_dict()
