# coding: utf-8

"""
    Regula FaceSDK Web API

    [Download OpenAPI specification](https://github.com/regulaforensics/FaceSDK-web-openapi) ### Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 6.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class PersonCreatedResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'int',
        'persons': '[SearchPerson]',
        'metadata': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
    }

    attribute_map = {
        'code': 'code',
        'persons': 'persons',
        'metadata': 'metadata',
    }

    def __init__(self, code=None, persons=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """PersonCreatedResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._persons = None
        self._metadata = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if persons is not None:
            self.persons = persons
        if metadata is not None:
            self.metadata = metadata

    @property
    def code(self):
        """Gets the code of this PersonCreatedResponse.  # noqa: E501

        Result code.  # noqa: E501

        :return: The code of this PersonCreatedResponse.  # noqa: E501
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this PersonCreatedResponse.

        Result code.  # noqa: E501

        :param code: The code of this PersonCreatedResponse.  # noqa: E501
        :type code: int
        """

        self._code = code

    @property
    def persons(self):
        """Gets the persons of this PersonCreatedResponse.  # noqa: E501

        Array of Person images.  # noqa: E501

        :return: The persons of this PersonCreatedResponse.  # noqa: E501
        :rtype: [SearchPerson]
        """
        return self._persons

    @persons.setter
    def persons(self, persons):
        """Sets the persons of this PersonCreatedResponse.

        Array of Person images.  # noqa: E501

        :param persons: The persons of this PersonCreatedResponse.  # noqa: E501
        :type persons: [SearchPerson]
        """

        self._persons = persons

    @property
    def metadata(self):
        """Gets the metadata of this PersonCreatedResponse.  # noqa: E501

        A free-form object containing person's extended attributes.  # noqa: E501

        :return: The metadata of this PersonCreatedResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PersonCreatedResponse.

        A free-form object containing person's extended attributes.  # noqa: E501

        :param metadata: The metadata of this PersonCreatedResponse.  # noqa: E501
        :type metadata: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersonCreatedResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PersonCreatedResponse):
            return True

        return self.to_dict() != other.to_dict()
